==> jc-1.4.0.tar.gz: gnu/xml/dom/ls/DomLSException.h <==
// public class gnu.xml.dom.ls.DomLSException

// class file dependencies
// @dep_class 35d1d4532032d62e gnu_xml_dom_ls_DomLSException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d9668b6408da7fa1 org_w3c_dom_ls_LSException

// header file dependencies
// @dep_header org_w3c_dom_ls_LSException

#include "org/w3c/dom/ls/LSException.h"

#ifndef _JC_gnu_xml_dom_ls_DomLSException_H_
#define _JC_gnu_xml_dom_ls_DomLSException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_ls_DomLSException$sub_refs	_jc_gnu_xml_dom_ls_DomLSException$sub_refs;
typedef struct _jc_gnu_xml_dom_ls_DomLSException$sub_nonrefs	_jc_gnu_xml_dom_ls_DomLSException$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_ls_DomLSException$refs	_jc_gnu_xml_dom_ls_DomLSException$refs;
typedef struct _jc_gnu_xml_dom_ls_DomLSException$nonrefs	_jc_gnu_xml_dom_ls_DomLSException$nonrefs;
typedef struct _jc_gnu_xml_dom_ls_DomLSException$object	_jc_gnu_xml_dom_ls_DomLSException$object;

typedef const struct _jc_gnu_xml_dom_ls_DomLSException$vmethods	_jc_gnu_xml_dom_ls_DomLSException$vmethods;
typedef const struct _jc_gnu_xml_dom_ls_DomLSException$vtable	_jc_gnu_xml_dom_ls_DomLSException$vtable;
typedef const struct _jc_gnu_xml_dom_ls_DomLSException$vtype	_jc_gnu_xml_dom_ls_DomLSException$vtype;

// Constructors
extern void _jc_gnu_xml_dom_ls_DomLSException$method$_init$6522263a4d459ea2(_jc_env *, struct _jc_gnu_xml_dom_ls_DomLSException$object *, jshort, struct _jc_java_lang_Exception$object *);

// Virtual methods structure
struct _jc_gnu_xml_dom_ls_DomLSException$vmethods {
};

// Vtable
struct _jc_gnu_xml_dom_ls_DomLSException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_ls_LSException$vmethods	org_w3c_dom_ls_LSException;
	_jc_gnu_xml_dom_ls_DomLSException$vmethods	gnu_xml_dom_ls_DomLSException;
};

// Vtype
struct _jc_gnu_xml_dom_ls_DomLSException$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_ls_DomLSException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_ls_DomLSException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_ls_DomLSException$refs {
    _jc_gnu_xml_dom_ls_DomLSException$sub_refs	gnu_xml_dom_ls_DomLSException;
    _jc_org_w3c_dom_ls_LSException$sub_refs	org_w3c_dom_ls_LSException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_ls_DomLSException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_ls_DomLSException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_ls_LSException$sub_nonrefs	org_w3c_dom_ls_LSException;
    _jc_gnu_xml_dom_ls_DomLSException$sub_nonrefs	gnu_xml_dom_ls_DomLSException;
};

// Object instance structure
struct _jc_gnu_xml_dom_ls_DomLSException$object {
	_jc_gnu_xml_dom_ls_DomLSException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_ls_DomLSException$vtype	*vtype;
	_jc_gnu_xml_dom_ls_DomLSException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_ls_DomLSException$vtype _jc_gnu_xml_dom_ls_DomLSException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_ls_DomLSException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_ls_DomLSException$class_object;

#endif	/* _JC_gnu_xml_dom_ls_DomLSException_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/ls/DomLSException.h <==
// public class gnu.xml.dom.ls.DomLSException

// class file dependencies
// @dep_class 35d1d4532032d62e gnu_xml_dom_ls_DomLSException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d9668b6408da7fa1 org_w3c_dom_ls_LSException

// header file dependencies
// @dep_header org_w3c_dom_ls_LSException

#include "org/w3c/dom/ls/LSException.h"

#ifndef _JC_gnu_xml_dom_ls_DomLSException_H_
#define _JC_gnu_xml_dom_ls_DomLSException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_ls_DomLSException$sub_refs	_jc_gnu_xml_dom_ls_DomLSException$sub_refs;
typedef struct _jc_gnu_xml_dom_ls_DomLSException$sub_nonrefs	_jc_gnu_xml_dom_ls_DomLSException$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_ls_DomLSException$refs	_jc_gnu_xml_dom_ls_DomLSException$refs;
typedef struct _jc_gnu_xml_dom_ls_DomLSException$nonrefs	_jc_gnu_xml_dom_ls_DomLSException$nonrefs;
typedef struct _jc_gnu_xml_dom_ls_DomLSException$object	_jc_gnu_xml_dom_ls_DomLSException$object;

typedef const struct _jc_gnu_xml_dom_ls_DomLSException$vmethods	_jc_gnu_xml_dom_ls_DomLSException$vmethods;
typedef const struct _jc_gnu_xml_dom_ls_DomLSException$vtable	_jc_gnu_xml_dom_ls_DomLSException$vtable;
typedef const struct _jc_gnu_xml_dom_ls_DomLSException$vtype	_jc_gnu_xml_dom_ls_DomLSException$vtype;

// Constructors
extern void _jc_gnu_xml_dom_ls_DomLSException$method$_init$6522263a4d459ea2(_jc_env *, struct _jc_gnu_xml_dom_ls_DomLSException$object *, jshort, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_dom_ls_DomLSException$vmethods {
};

// Vtable
struct _jc_gnu_xml_dom_ls_DomLSException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_ls_LSException$vmethods	org_w3c_dom_ls_LSException;
	_jc_gnu_xml_dom_ls_DomLSException$vmethods	gnu_xml_dom_ls_DomLSException;
};

// Vtype
struct _jc_gnu_xml_dom_ls_DomLSException$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_ls_DomLSException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_ls_DomLSException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_ls_DomLSException$refs {
    _jc_gnu_xml_dom_ls_DomLSException$sub_refs	gnu_xml_dom_ls_DomLSException;
    _jc_org_w3c_dom_ls_LSException$sub_refs	org_w3c_dom_ls_LSException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_ls_DomLSException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_ls_DomLSException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_ls_LSException$sub_nonrefs	org_w3c_dom_ls_LSException;
    _jc_gnu_xml_dom_ls_DomLSException$sub_nonrefs	gnu_xml_dom_ls_DomLSException;
};

// Object instance structure
struct _jc_gnu_xml_dom_ls_DomLSException$object {
	_jc_gnu_xml_dom_ls_DomLSException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_ls_DomLSException$vtype	*vtype;
	_jc_gnu_xml_dom_ls_DomLSException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_ls_DomLSException$vtype _jc_gnu_xml_dom_ls_DomLSException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_ls_DomLSException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_ls_DomLSException$class_object;

#endif	/* _JC_gnu_xml_dom_ls_DomLSException_H_ */
